@@ -1,7 +1,5 @@
 from django.db import models
 
-# Create your models here.
-
 
 class xsanio_client(models.Model):
     """Can be a client, can be an MDC -- the only thing that matters
@@ -37,6 +35,7 @@ class stat_entry(models.Model):
     host = models.ForeignKey(xsanio_client)
     disk = models.CharField(max_length=255)
     value = models.FloatField(null=True, blank=True, default=0.0)
+    time_stamp = models.DateTimeField(auto_now_add=True)
 
     def __unicode__(self):
         return "%s: %s for %s" % (self.host, self.type, self.disk)
